==> connector-service-1.1.6-20220107.062154-1-sources.jar: com/bizvane/connectorservice/entity/common/MemberOpenCardRequestVO.java <==
package com.bizvane.connectorservice.entity.common;

import com.bizvane.connectorservice.entity.base.BaseModel;
import lombok.ToString;

/**
 * @author liuying
 * @date 2018/8/9
 * @description
 */
@ToString
public class MemberOpenCardRequestVO extends BaseModel{

    /**
     * 微信用户的openId
     */
    private String openId;

    /**
     * 微信用户的unionId
     */
    private String unionId;

    /**
     * 手机号
     */
    private String phone;

    /**
     * 会员姓名
     */
    private String name;

    /**
     * 等级Code
     */
    private String levelCode;

    /**
     * 会员性别(1男   0女)
     */
    private Integer gender;

    /**
     * 会员生日 pattern = "yyyyMMdd"
     */
    private String birthday;

    /**
     * 开卡门店编号
     */
    private String openStoreCode;

    /**
     * 开卡导购编号
     */
    private String openGuideCode;

    /**
     * 省份
     */
    private String province;

    /**
     * 城市
     */
    private String city;

    /**
     * 区县
     */
    private String county;

    /**
     * 详细地址
     */
    private String address;

    /**
     * 有效期
     */
    private String effectiveTime;

    /**
     * 开卡来源
     */
    private String source;

    /**
     * 邮箱
     */
    private String email;

    /**
     * 开卡区别来源UR
     */
    private String registerType;

    /**
     * 所属门店UR
     */
    private String serviceStoreCode;

    /**
     * 密码UR
     */
    private String password;

    private String taobaoNick;

    /**
     * 361备注
     */
    private  String remark;

    /**
     * 361身份证号
     */
    private String idCard;

    /**
     * 会员名称
     * */
    private String taobaoName;

    /**
     * 手机区域号
     * */
    private String phoneAreaCode;

    /**
     * 有赞openId
     * */
    private String yzOpenId;

    /**
     * 默认开卡门店
     * */
    private String defaultOpenStoreCode;

    /**
     * 默认开卡导购
     */
    private String defaultOpenGuideCode;

    /**
     * 雷朵 开卡导购名称
     */
    private String openGuideName;

    /**
     * 雷朵 标志
     * */
    private Boolean radoFlag = Boolean.FALSE;

    /**
     * 雷朵 更新时间
     * */
    private String offlineUpdateDate;

    /**
     * 会员来源渠道id
     */
    private Integer kaiKaQuDaoId;

    /**
     * 会员来源渠道描述
     */
    private String kaiKaiMiaoShuId;

    /**
     * 推荐人会员卡号
     */
    private String InviterCardNo;

    /**
     * 推荐人会员姓名
     */
    private String InviterName;

    /**
     * 自建应用外部联系人ID
     */
    private String applicationExternalUserId;

    public String getOfflineUpdateDate() {
        return offlineUpdateDate;
    }

    public void setOfflineUpdateDate(String offlineUpdateDate) {
        this.offlineUpdateDate = offlineUpdateDate;
    }

    public Boolean getRadoFlag() {
        return radoFlag;
    }

    public void setRadoFlag(Boolean radoFlag) {
        this.radoFlag = radoFlag;
    }

    public String getOpenGuideName() {
        return openGuideName;
    }

    public void setOpenGuideName(String openGuideName) {
        this.openGuideName = openGuideName;
    }

    public String getDefaultOpenStoreCode() {
        return defaultOpenStoreCode;
    }

    public void setDefaultOpenStoreCode(String defaultOpenStoreCode) {
        this.defaultOpenStoreCode = defaultOpenStoreCode;
    }

    public String getDefaultOpenGuideCode() {
        return defaultOpenGuideCode;
    }

    public void setDefaultOpenGuideCode(String defaultOpenGuideCode) {
        this.defaultOpenGuideCode = defaultOpenGuideCode;
    }

    /**
     * 会员唯一标识
     */
    private String erpId;

    public String getYzOpenId() {
        return yzOpenId;
    }

    public void setYzOpenId(String yzOpenId) {
        this.yzOpenId = yzOpenId;
    }

    public String getPhoneAreaCode() {
        return phoneAreaCode;
    }

    public void setPhoneAreaCode(String phoneAreaCode) {
        this.phoneAreaCode = phoneAreaCode;
    }

    public String getTaobaoName() {
        return taobaoName;
    }

    public void setTaobaoName(String taobaoName) {
        this.taobaoName = taobaoName;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getEffectiveTime() {
        return effectiveTime;
    }

    public void setEffectiveTime(String effectiveTime) {
        this.effectiveTime = effectiveTime;
    }

    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getUnionId() {
        return unionId;
    }

    public void setUnionId(String unionId) {
        this.unionId = unionId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getLevelCode() {
        return levelCode;
    }

    public void setLevelCode(String levelCode) {
        this.levelCode = levelCode;
    }

    public Integer getGender() {
        return gender;
    }

    public void setGender(Integer gender) {
        this.gender = gender;
    }

    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }

    public String getOpenStoreCode() {
        return openStoreCode;
    }

    public void setOpenStoreCode(String openStoreCode) {
        this.openStoreCode = openStoreCode;
    }

    public String getOpenGuideCode() {
        return openGuideCode;
    }

    public void setOpenGuideCode(String openGuideCode) {
        this.openGuideCode = openGuideCode;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getCounty() {
        return county;
    }

    public void setCounty(String county) {
        this.county = county;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getRegisterType() {
        return registerType;
    }

    public void setRegisterType(String registerType) {
        this.registerType = registerType;
    }

    public String getServiceStoreCode() {
        return serviceStoreCode;
    }

    public void setServiceStoreCode(String serviceStoreCode) {
        this.serviceStoreCode = serviceStoreCode;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public String getTaobaoNick() {
        return taobaoNick;
    }

    public void setTaobaoNick(String taobaoNick) {
        this.taobaoNick = taobaoNick;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }

    public String getErpId() {
        return erpId;
    }

    public void setErpId(String erpId) {
        this.erpId = erpId;
    }

    public Integer getKaiKaQuDaoId() {
        return kaiKaQuDaoId;
    }

    public void setKaiKaQuDaoId(Integer kaiKaQuDaoId) {
        this.kaiKaQuDaoId = kaiKaQuDaoId;
    }

    public String getKaiKaiMiaoShuId() {
        return kaiKaiMiaoShuId;
    }

    public void setKaiKaiMiaoShuId(String kaiKaiMiaoShuId) {
        this.kaiKaiMiaoShuId = kaiKaiMiaoShuId;
    }

    public String getInviterCardNo() {
        return InviterCardNo;
    }

    public void setInviterCardNo(String inviterCardNo) {
        InviterCardNo = inviterCardNo;
    }

    public String getInviterName() {
        return InviterName;
    }

    public void setInviterName(String inviterName) {
        InviterName = inviterName;
    }

    public String getApplicationExternalUserId() {
        return applicationExternalUserId;
    }

    public void setApplicationExternalUserId(String applicationExternalUserId) {
        this.applicationExternalUserId = applicationExternalUserId;
    }
}

==> connector-service-1.1.7-20220111.082047-1-sources.jar: com/bizvane/connectorservice/entity/common/MemberOpenCardRequestVO.java <==
package com.bizvane.connectorservice.entity.common;

import com.bizvane.connectorservice.entity.base.BaseModel;
import lombok.ToString;

/**
 * @author liuying
 * @date 2018/8/9
 * @description
 */
@ToString
public class MemberOpenCardRequestVO extends BaseModel{

    /**
     * 微信用户的openId
     */
    private String openId;

    /**
     * 微信用户的unionId
     */
    private String unionId;

    /**
     * 手机号
     */
    private String phone;

    /**
     * 会员姓名
     */
    private String name;

    /**
     * 等级Code
     */
    private String levelCode;

    /**
     * 会员性别(1男   0女)
     */
    private Integer gender;

    /**
     * 会员生日 pattern = "yyyyMMdd"
     */
    private String birthday;

    /**
     * 开卡门店编号
     */
    private String openStoreCode;

    /**
     * 开卡导购编号
     */
    private String openGuideCode;

    /**
     * 省份
     */
    private String province;

    /**
     * 城市
     */
    private String city;

    /**
     * 区县
     */
    private String county;

    /**
     * 详细地址
     */
    private String address;

    /**
     * 有效期
     */
    private String effectiveTime;

    /**
     * 开卡来源
     */
    private String source;

    /**
     * 邮箱
     */
    private String email;

    /**
     * 开卡区别来源UR
     */
    private String registerType;

    /**
     * 所属门店UR
     */
    private String serviceStoreCode;

    /**
     * 密码UR
     */
    private String password;

    private String taobaoNick;

    /**
     * 361备注
     */
    private  String remark;

    /**
     * 361身份证号
     */
    private String idCard;

    /**
     * 会员名称
     * */
    private String taobaoName;

    /**
     * 手机区域号
     * */
    private String phoneAreaCode;

    /**
     * 有赞openId
     * */
    private String yzOpenId;

    /**
     * 默认开卡门店
     * */
    private String defaultOpenStoreCode;

    /**
     * 默认开卡导购
     */
    private String defaultOpenGuideCode;

    /**
     * 雷朵 开卡导购名称
     */
    private String openGuideName;

    /**
     * 雷朵 标志
     * */
    private Boolean radoFlag = Boolean.FALSE;

    /**
     * 雷朵 更新时间
     * */
    private String offlineUpdateDate;

    /**
     * 会员来源渠道id
     */
    private Integer kaiKaQuDaoId;

    /**
     * 会员来源渠道描述
     */
    private String kaiKaiMiaoShuId;

    /**
     * 推荐人会员卡号
     */
    private String InviterCardNo;

    /**
     * 推荐人会员姓名
     */
    private String InviterName;

    /**
     * 自建应用外部联系人ID
     */
    private String applicationExternalId;

    public String getOfflineUpdateDate() {
        return offlineUpdateDate;
    }

    public void setOfflineUpdateDate(String offlineUpdateDate) {
        this.offlineUpdateDate = offlineUpdateDate;
    }

    public Boolean getRadoFlag() {
        return radoFlag;
    }

    public void setRadoFlag(Boolean radoFlag) {
        this.radoFlag = radoFlag;
    }

    public String getOpenGuideName() {
        return openGuideName;
    }

    public void setOpenGuideName(String openGuideName) {
        this.openGuideName = openGuideName;
    }

    public String getDefaultOpenStoreCode() {
        return defaultOpenStoreCode;
    }

    public void setDefaultOpenStoreCode(String defaultOpenStoreCode) {
        this.defaultOpenStoreCode = defaultOpenStoreCode;
    }

    public String getDefaultOpenGuideCode() {
        return defaultOpenGuideCode;
    }

    public void setDefaultOpenGuideCode(String defaultOpenGuideCode) {
        this.defaultOpenGuideCode = defaultOpenGuideCode;
    }

    /**
     * 会员唯一标识
     */
    private String erpId;

    public String getYzOpenId() {
        return yzOpenId;
    }

    public void setYzOpenId(String yzOpenId) {
        this.yzOpenId = yzOpenId;
    }

    public String getPhoneAreaCode() {
        return phoneAreaCode;
    }

    public void setPhoneAreaCode(String phoneAreaCode) {
        this.phoneAreaCode = phoneAreaCode;
    }

    public String getTaobaoName() {
        return taobaoName;
    }

    public void setTaobaoName(String taobaoName) {
        this.taobaoName = taobaoName;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getEffectiveTime() {
        return effectiveTime;
    }

    public void setEffectiveTime(String effectiveTime) {
        this.effectiveTime = effectiveTime;
    }

    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getUnionId() {
        return unionId;
    }

    public void setUnionId(String unionId) {
        this.unionId = unionId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getLevelCode() {
        return levelCode;
    }

    public void setLevelCode(String levelCode) {
        this.levelCode = levelCode;
    }

    public Integer getGender() {
        return gender;
    }

    public void setGender(Integer gender) {
        this.gender = gender;
    }

    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }

    public String getOpenStoreCode() {
        return openStoreCode;
    }

    public void setOpenStoreCode(String openStoreCode) {
        this.openStoreCode = openStoreCode;
    }

    public String getOpenGuideCode() {
        return openGuideCode;
    }

    public void setOpenGuideCode(String openGuideCode) {
        this.openGuideCode = openGuideCode;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getCounty() {
        return county;
    }

    public void setCounty(String county) {
        this.county = county;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getRegisterType() {
        return registerType;
    }

    public void setRegisterType(String registerType) {
        this.registerType = registerType;
    }

    public String getServiceStoreCode() {
        return serviceStoreCode;
    }

    public void setServiceStoreCode(String serviceStoreCode) {
        this.serviceStoreCode = serviceStoreCode;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public String getTaobaoNick() {
        return taobaoNick;
    }

    public void setTaobaoNick(String taobaoNick) {
        this.taobaoNick = taobaoNick;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }

    public String getErpId() {
        return erpId;
    }

    public void setErpId(String erpId) {
        this.erpId = erpId;
    }

    public Integer getKaiKaQuDaoId() {
        return kaiKaQuDaoId;
    }

    public void setKaiKaQuDaoId(Integer kaiKaQuDaoId) {
        this.kaiKaQuDaoId = kaiKaQuDaoId;
    }

    public String getKaiKaiMiaoShuId() {
        return kaiKaiMiaoShuId;
    }

    public void setKaiKaiMiaoShuId(String kaiKaiMiaoShuId) {
        this.kaiKaiMiaoShuId = kaiKaiMiaoShuId;
    }

    public String getInviterCardNo() {
        return InviterCardNo;
    }

    public void setInviterCardNo(String inviterCardNo) {
        InviterCardNo = inviterCardNo;
    }

    public String getInviterName() {
        return InviterName;
    }

    public void setInviterName(String inviterName) {
        InviterName = inviterName;
    }

    public String getApplicationExternalId() {
        return applicationExternalId;
    }

    public void setApplicationExternalId(String applicationExternalId) {
        this.applicationExternalId = applicationExternalId;
    }
}
